<?php
/*
 * leFooter Admin Settings
 */

class Settings_API_Tabs_WPLFTR_Plugin {
	
	/*
	 * For easier overriding we declared the keys
	 * here as well as our tabs array which is populated
	 * when registering settings
	 */
	private $general_settings_key = 'wplftr_general_settings';
	private $advanced_settings_key = 'wplftr_advanced_settings';
	private $plugin_options_key = 'wplftr_plugin_options';
	private $plugin_settings_tabs = array();
	
	/*
	 * Fired during plugins_loaded (very very early),
	 * so don't miss-use this, only actions and filters,
	 * current ones speak for themselves.
	 */
	function __construct() {
		add_action( 'init', array( &$this, 'wplftr_load_settings' ) );
		add_action( 'admin_init', array( &$this, 'wplftr_register_general_settings' ) );
		// add_action( 'admin_init', array( &$this, 'wplftr_register_advanced_settings' ) );
		add_action( 'admin_menu', array( &$this, 'wplftr_add_admin_menus' ) );
	}
	
	/*
	 * Loads both the general and advanced settings from
	 * the database into their respective arrays. Uses
	 * array_merge to merge with default values if they're
	 * missing.
	 */
	function wplftr_load_settings() {
		$this->general_settings = (array) get_option( $this->general_settings_key );
		// $this->advanced_settings = (array) get_option( $this->advanced_settings_key );
	}
	
	/*
	 * Registers the general settings via the Settings API,
	 * appends the setting to the tabs array of the object.
	 */
	function wplftr_register_general_settings() {
		$this->plugin_settings_tabs[$this->general_settings_key] = 'WP - leFooter Settings';
		
		register_setting( $this->general_settings_key, $this->general_settings_key );
		add_settings_section( 'location_section', 'General Settings', array( &$this, 'wplftr_section_position_desc' ), $this->general_settings_key );
		add_settings_field( 'location_option', 'Location', array( &$this, 'wplftr_checkbox_location_option' ), $this->general_settings_key, 'location_section' );
		add_settings_section( 'theme_option', ' ', array( &$this, 'wplftr_theme_general_option' ), $this->general_settings_key);
		add_settings_section( 'custom_section', ' ', array( &$this, 'wplftr_section_custom_theme_content' ), $this->general_settings_key );
		add_settings_section( 'custom_texture', ' ', array( &$this, 'wplftr_section_custom_theme_texture' ), $this->general_settings_key );
		add_settings_section( 'custom_animation', ' ', array( &$this, 'wplftr_section_custom_theme_animation' ), $this->general_settings_key );
	}

	
	/*
	 * Registers the advanced settings and appends the
	 * key to the plugin settings tabs array.
	 */
	// function wplftr_register_advanced_settings() {
	// 	$this->plugin_settings_tabs[$this->advanced_settings_key] = 'Statistic';
		
	// 	register_setting( $this->advanced_settings_key, $this->advanced_settings_key );
	// 	add_settings_section( 'section_advanced', 'Statistic', array( &$this, 'wplftr_section_advanced_desc' ), $this->advanced_settings_key );
	// 	add_settings_section( 'statistic', ' ', array( &$this, 'wplftr_section_statistic' ), $this->advanced_settings_key );
	// }
	
	/*
	 * The following methods provide descriptions
	 * for their respective sections, used as callbacks
	 * with add_settings_section
	 */
	function wplftr_section_position_desc() { ?> 
		<table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row"><label>Inner Width</label></th>
					<td>
						<input type="text" name="<?php echo $this->general_settings_key; ?>[width]" value="<?php echo $this->general_settings['width'];?>" /> px
					</td>
				</tr>
				<tr valign="top">
					<th scope="row"><label>Responsive</label></th>
					<td>
						<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[responsive]" value="1" <?php echo ( isset($this->general_settings['responsive']) ) ? 'checked=""checked' : ''; ?> /> <em>Turn responsive for browser width less than 768px only.</em><br />
					</td>
				</tr>
			</tbody>
		</table><br />
	<?php echo 'Please select the locations that you wish to allow the WP-leFooter to show.'; }
	function wplftr_section_custom_theme_content() { ?>
		<div id="wplftr-custom-theme">
			<h3>Custom Color Scheme</h3>
			Create your own WP-leFooter color scheme by using the following options.
			<div style="clear:both;"></div>
			<div style="float:left;width:440px;">
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label>Toggle Opener Background</label></th>
							<td><input type="text" id="coloropener" name="<?php echo $this->general_settings_key; ?>[coloropener]" class="colorwell" value="<?php echo (!empty($this->general_settings['coloropener'])) ? $this->general_settings['coloropener'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Inner Background</label></th>
							<td><input type="text" id="colorbg" name="<?php echo $this->general_settings_key; ?>[colorbg]" class="colorwell" value="<?php echo (!empty($this->general_settings['colorbg'])) ? $this->general_settings['colorbg'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Headings</label></th>
							<td><input type="text" id="colorhead" name="<?php echo $this->general_settings_key; ?>[colorhead]" class="colorwell" value="<?php echo (!empty($this->general_settings['colorhead'])) ? $this->general_settings['colorhead'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Links</label></th>
							<td><input type="text" id="colorlink" name="<?php echo $this->general_settings_key; ?>[colorlink]" class="colorwell" value="<?php echo (!empty($this->general_settings['colorlink'])) ? $this->general_settings['colorlink'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Paragraph</label></th>
							<td><input type="text" id="colorp" name="<?php echo $this->general_settings_key; ?>[colorp]" class="colorwell" value="<?php echo (!empty($this->general_settings['colorp'])) ? $this->general_settings['colorp'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Lists</label></th>
							<td><input type="text" id="colorlist" name="<?php echo $this->general_settings_key; ?>[colorlist]" class="colorwell" value="<?php echo (!empty($this->general_settings['colorlist'])) ? $this->general_settings['colorlist'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Button Text</label></th>
							<td><input type="text" id="colorbt" name="<?php echo $this->general_settings_key; ?>[colorbt]" class="colorwell" value="<?php echo (!empty($this->general_settings['colorbt'])) ? $this->general_settings['colorbt'] : ' ' ; ?>" /></td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Button Background</label></th>
							<td><input type="text" id="colorb" name="<?php echo $this->general_settings_key; ?>[colorb]" class="colorwell" value="<?php echo (!empty($this->general_settings['colorb'])) ? $this->general_settings['colorb'] : ' ' ; ?>" /></td>
						</tr>
					</tbody>
				</table>
			</div>
			<div style="float:left; width:300px; padding-left:70px; padding-top:15px;">
				<div id="wplftr-picker"></div>
			</div>
			<div style="clear:both;"></div>
		</div>
	<?php }
	function wplftr_section_custom_theme_texture() { ?>
		<div id="wplftr-custom-texture">
			<h3>Custom Background Texture</h3>
			Enhance your WP - leFooter design by adding any of the following textures
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label>Background Texture</label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[texture]"  >
									<option value="">Select Texture</option>
									<option value="diagonal" <?php echo ($this->general_settings['texture']== "diagonal") ? 'selected=""selected' : ''; ?> >Diagonal Lines</option>
									<option value="diamonds" <?php echo ($this->general_settings['texture']== "diamonds") ? 'selected=""selected' : ''; ?> >Diamonds</option>
									<option value="noise" <?php echo ($this->general_settings['texture']== "noise") ? 'selected=""selected' : ''; ?> >Noise</option>
									<option value="pixelated" <?php echo ($this->general_settings['texture']== "pixelated") ? 'selected=""selected' : ''; ?> >Pixelated</option>
									<option value="scan-lines" <?php echo ($this->general_settings['texture']== "scan-lines") ? 'selected=""selected' : ''; ?> >Scan-Lines</option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>

		<div id="wplftr-custom-opener-position">
			<h3>Toggle Opener Position</h3>
			Change Toggle Opener Position to either Left, Center or Right
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label>Position</label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[openerp]"  >
									<option value="">Select Position</option>
									<option value="left" <?php echo ($this->general_settings['openerp']== "left") ? 'selected=""selected' : ''; ?> >Left</option>
									<option value="center" <?php echo ($this->general_settings['openerp']== "center") ? 'selected=""selected' : ''; ?> >Center</option>
									<option value="right" <?php echo ($this->general_settings['openerp']== "right") ? 'selected=""selected' : ''; ?> >Right</option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>

	<?php }

	function wplftr_section_advanced_desc() { echo 'Advanced section description goes here.'; }
	
	/*
	 * Pages you want the footer to appear
	 */
	function wplftr_checkbox_location_option() {
		// print_r( $this->general_settings );
		?>
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][home]" value="1" <?php echo ( isset($this->general_settings['location']['home']) ) ? 'checked=""checked' : ''; ?> /> Home page - <em>The front page of the blog (if set to a static page), or the main blog page (if set to your latest posts).</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][blog]" value="1" <?php echo ( isset($this->general_settings['location']['blog']) ) ? 'checked=""checked' : ''; ?> /> Blog page - <em>The home page of the blog if is set to your latest posts, or the posts page if the home page is set to a static page</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][posts]" value="1" <?php echo ( isset($this->general_settings['location']['posts'] ) ) ? 'checked=""checked' : ''; ?> /> Posts - <em>Single post pages</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][pages]" value="1" <?php echo ( isset($this->general_settings['location']['pages']) ) ? 'checked=""checked' : ''; ?> /> Pages - <em>Individual Wordpress pages</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][category]" value="1" <?php echo ( isset($this->general_settings['location']['category']) ) ? 'checked=""checked' : ''; ?> /> Category archives - <em>Category archive pages</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][date]" value="1" <?php echo ( isset($this->general_settings['location']['date']) ) ? 'checked=""checked' : ''; ?> /> Date archives - <em>Date archive pages</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][tag]" value="1" <?php echo ( isset($this->general_settings['location']['tag']) ) ? 'checked=""checked' : ''; ?> /> Tag archives - <em>Tag archive pages</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][author]" value="1" <?php echo ( isset($this->general_settings['location']['author']) ) ? 'checked=""checked' : ''; ?> /> Author archives - <em>Author archive pages</em><br />
		<input type="checkbox" name="<?php echo $this->general_settings_key; ?>[location][search]" value="1" <?php echo ( isset($this->general_settings['location']['search']) ) ? 'checked=""checked' : ''; ?> /> Search results - <em>Search results pages</em><br />
		<?php
	}
	function wplftr_theme_general_option() {
		// print_r( $this->general_settings );
		?>
		<div id="wplftr-custom-theme-options">
			<h3>Themes</h3>
			Select from WP - leFooter awesome predefined themes
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label>Themes</label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[theme]"  >
									<option value="">Select Theme</option>
									<option value="minimalist-white" <?php echo ($this->general_settings['theme']== "minimalist-white") ? 'selected=""selected' : ''; ?> >Minimalist Light</option>
									<option value="minimalist-dark" <?php echo ($this->general_settings['theme']== "minimalist-dark") ? 'selected=""selected' : ''; ?> >Minimalist Dark</option>
									<option value="colored" <?php echo ($this->general_settings['theme']== "colored") ? 'selected=""selected' : ''; ?> >Colored</option>
									<option value="gray" <?php echo ($this->general_settings['theme']== "gray") ? 'selected=""selected' : ''; ?> >Gray Block</option>
									<option value="transparent" <?php echo ($this->general_settings['theme']== "transparent") ? 'selected=""selected' : ''; ?> >Transparent</option>
								</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>
		<?php
	}
	
	/*
	 * Animation speed and easing effect
	 */
	function wplftr_section_custom_theme_animation(){ 
		$easing = array('swing','easeInQuad','easeOutQuad','easeInOutQuad','easeInCubic','easeOutCubic','easeInOutCubic','easeInQuart','easeOutQuart','easeInOutQuart','easeInQuint','easeOutQuint','easeInOutQuint','easeInSine','easeOutSine','easeInOutSine','easeInExpo','easeOutExpo','easeInOutExpo','easeInCirc','easeOutCirc','easeInOutCirc','easeInElastic','easeOutElastic','easeInOutElastic','easeInBack','easeOutBack','easeInOutBack','easeInBounce','easeOutBounce','easeInOutBounce')
		?>
		<div id="wplftr-custom-theme-options">
			<h3>Animation Settings</h3>
			Change animation speed and easing effect
			<div style="clear:both;"></div>
				<table class="form-table">
					<tbody>
						<tr valign="top">
							<th scope="row"><label>Animation Speed</label></th>
							<td>
								<input type="text" name="<?php echo $this->general_settings_key; ?>[speed]" value="<?php echo $this->general_settings['speed'];?>" /> ms
							</td>
						</tr>
						<tr valign="top">
							<th scope="row"><label>Easing Effect</label></th>
							<td>
								<select name="<?php echo $this->general_settings_key; ?>[easing]"  >
									<option value="">Select Effect</option>
									<?php foreach ($easing as $key => $value) { ?>
									<option value="<?php echo $value;?>" <?php echo ($this->general_settings['easing']== $value) ? 'selected=""selected' : ''; ?> ><?php echo $value;?></option>
									<?php } ?>
									
									</select>
							</td>
						</tr>
					</tbody>
				</table>
			<div style="clear:both;"></div>
		</div>
	<?php }
	/*
	 * Advanced Option field callback, same as above.
	 */
	function wplftr_field_advanced_option() {
		?>
		<input type="text" name="<?php echo $this->advanced_settings_key; ?>[advanced_option]" value="<?php echo esc_attr( $this->advanced_settings['advanced_option'] ); ?>" />
		<?php
	}
	
	/*
	 * Called during admin_menu, adds an options
	 * page under Settings called My Settings, rendered
	 * using the wplftr_plugin_options_page method.
	 */
	function wplftr_add_admin_menus() {
		add_options_page( 'WP-leFooter Setting', 'WP-leFooter Setting', 'manage_options', $this->plugin_options_key, array( &$this, 'wplftr_plugin_options_page' ) );
	}
	
	/*
	 * Plugin Options page rendering goes here, checks
	 * for active tab and replaces key with the related
	 * settings key. Uses the wplftr_plugin_options_tabs method
	 * to render the tabs.
	 */
	function wplftr_plugin_options_page() {
		$tab = isset( $_GET['tab'] ) ? $_GET['tab'] : $this->general_settings_key;
		?>
		<div class="wrap">
			<?php $this->wplftr_plugin_options_tabs(); ?>
			<form method="post" action="options.php">
				<?php wp_nonce_field( 'update-options' ); ?>
				<?php settings_fields( $tab ); ?>
				<?php do_settings_sections( $tab ); ?>
				<?php 
				if(function_exists('submit_button')) { submit_button(); } else { ?>
				<p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary" value="Save Changes"></p>
				<?php }?>
			</form>
		</div>
		<?php
	}
	
	/*
	 * Renders our tabs in the plugin options page,
	 * walks through the object's tabs array and prints
	 * them one by one. Provides the heading for the
	 * wplftr_plugin_options_page method.
	 */
	function wplftr_plugin_options_tabs() {
		$current_tab = isset( $_GET['tab'] ) ? $_GET['tab'] : $this->general_settings_key;

		screen_icon();
		echo '<h2 class="nav-tab-wrapper">';
		foreach ( $this->plugin_settings_tabs as $tab_key => $tab_caption ) {
			$active = $current_tab == $tab_key ? 'nav-tab-active' : '';
			echo '<a class="nav-tab ' . $active . '" href="?page=' . $this->plugin_options_key . '&tab=' . $tab_key . '">' . $tab_caption . '</a>';	
		}
		echo '</h2>';
	}
};

// Initialize the plugin
add_action( 'plugins_loaded', create_function( '', '$settings_api_tabs_wplftr_plugin = new Settings_API_Tabs_WPLFTR_Plugin;' ) );

?>